%define name gettext
%define version 0.10.40
%define prefix %{_prefix}
%define release 4mdk
%define major 1
%define libver %{major}.0.1
%define lib_name libintl%{major}

Name: %{name}
Summary: GNU libraries and utilities for producing multi-lingual messages.
Version: %{version}
Release: %{release}
License: GPL
Group: System/Libraries
Source: ftp://ftp.gnu.org/pub/gnu/gettext-%version.tar.bz2
Source1: po-mode-init.el
URL: http://www.gnu.org/software/gettext/
Patch1: gettext-0.10.35-jbj.patch.bz2
Patch2: gettext-0.10.40-arm.patch.bz2
Patch4: gettext-fix-gettextize.patch.bz2
# patch to not issue error messages and warnings with some charset encodings
# we support in MDK. -- pablo
Patch5: gettext-0.10.37-charsets.patch.bz2
Patch6: gettext-0.10.40-highlight-nbsp.patch.bz2
Packager: Guillaume Cottenceau <gc@mandrakesoft.com>
Requires: %{name}-base = %{version}
BuildRoot: %{_tmppath}/%{name}-%{version}-buildroot

%description
The GNU gettext package provides a set of tools and documentation for producing
multi-lingual messages in programs. Tools include a set of conventions about
how programs should be written to support message catalogs, a directory and
file naming organization for the message catalogs, a runtime library which
supports the retrieval of translated messages, and stand-alone programs for
handling the translatable and the already translated strings. Gettext provides
an easy to use library and tools for creating, using, and modifying natural
language catalogs and is a powerful and simple method for internationalizing
programs.

If you would like to internationalize or incorporate multi-lingual messages
into programs that you're developing, you should install gettext.

%package -n %{lib_name}
Summary: The dynamic libintl library for the gettext package.
Group: System/Libraries
Provides: libintl

%description -n %{lib_name}
This package contains the libintl library for the gettext package.

%package devel
Summary: GNU libraries and utilities for producing multi-lingual messages.
Group: Development/Other
Requires: %{name} = %{version}

%description devel
Header files, used when the libc does not provide code of handling
multi-lingual messages.

%package base
Summary: GNU libraries and utilities for producing multi-lingual messages.
Group: Development/Other
Requires: %{lib_name}

%description base
The base package which includes the gettext binary.

%prep
rm -rf $RPM_BUILD_ROOT
%setup -q -n gettext-%{version}
%patch1 -p1 -b .jbj
%patch2 -p1 -b .arm
%patch4 -p0
%patch5 -p1
%patch6 -p1

%build
autoconf
%configure --enable-shared --with-included-gettext
# (gc) #### DO NOT USE #### percent-make or you'll suffer so much that hell would be a pleasure for you
make

%install
rm -rf $RPM_BUILD_ROOT
%makeinstall lispdir=$RPM_BUILD_ROOT%{_datadir}/emacs/site-lisp gettextsrcdir=$RPM_BUILD_ROOT%{_datadir}/gettext/intl

# fixups for what make install doesn't do for us
# required for gettextize to work properly
mv $RPM_BUILD_ROOT%{_datadir}/gettext/intl/ABOUT-NLS $RPM_BUILD_ROOT%{_datadir}/gettext

mkdir -p $RPM_BUILD_ROOT%{_datadir}/gettext/po
cp po/Makefile.in.in $RPM_BUILD_ROOT%{_datadir}/gettext/po
chmod -R og+rX $RPM_BUILD_ROOT%{_datadir}/gettext/po

rm -f $RPM_BUILD_ROOT%{_includedir}/libintl.h

install -d $RPM_BUILD_ROOT%{_sysconfdir}/emacs/site-start.d
install -m 644 %{SOURCE1} $RPM_BUILD_ROOT%{_sysconfdir}/emacs/site-start.d/%{name}.el

# remove non-standard lc directories
for i in en@boldquot en@quot zh; do rm -rf $RPM_BUILD_ROOT/%{_datadir}/locale/$i; done

%find_lang gettext

cd $RPM_BUILD_ROOT
mkdir -p bin
mkdir -p lib
mv usr/bin/gettext bin
ln -s ../../bin/gettext usr/bin/gettext
mv usr/lib/libintl.so.* lib/
ln -sf ../../lib/libintl.so.%{libver} usr/lib/libintl.so

%clean
rm -rf $RPM_BUILD_ROOT

%post
%_install_info gettext.info

%post -n %{lib_name} -p /sbin/ldconfig

%preun
%_remove_install_info gettext.info

%postun -n %{lib_name} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc README COPYING ABOUT-NLS AUTHORS BUGS DISCLAIM NEWS THANKS TODO
%config(noreplace) %{_sysconfdir}/emacs/site-start.d/*.el
%{_bindir}/msgcmp
%{_bindir}/msgcomm
%{_bindir}/msgfmt
%{_bindir}/ngettext
%{_bindir}/msgmerge
%{_bindir}/msgunfmt
%{_bindir}/xgettext
%{_infodir}/gettext*
%{_datadir}/aclocal/*
%{_datadir}/emacs/site-lisp/*.el
%{_mandir}/*/*

%files base -f gettext.lang
%defattr(-,root,root)
%doc README
/bin/gettext
%{_bindir}/gettext

%files -n %{lib_name}
%defattr(-,root,root)
%doc README
/lib/lib*.so.*

%files devel
%defattr(-,root,root)
%doc README COPYING
%{_libdir}/libintl.a
%{_libdir}/libintl.la
%{_libdir}/libintl.so
%{_bindir}/gettextize
%{_datadir}/gettext

%changelog
* Mon Feb 25 2002 Pixel <pixel@mandrakesoft.com> 0.10.40-4mdk
- highlight-nbsp (suggested by gc)

* Wed Oct 17 2001 Guillaume Cottenceau <gc@mandrakesoft.com> 0.10.40-3mdk
- fix no-documentation

* Mon Oct 15 2001 Guillaume Cottenceau <gc@mandrakesoft.com> 0.10.40-2mdk
- fix invalid-lc-messages-dir
- fix patch-not-applied
- fix obsolete-tag Copyright
- revive three Patches (please packagers -> when a patch don't "pass"
  anymore, don't just ignore it, do your work!!)
- use RH site-start Emacs resource file for po-mode
- more docs

* Fri Sep 28 2001 Guillaume Cottenceau <gc@mandrakesoft.com> 0.10.40-1mdk
- new version

* Wed Sep 12 2001 Guillaume Cottenceau <gc@mandrakesoft.com> 0.10.39-2mdk
- mark emacs site-start file as conffile

* Tue Jul 31 2001 Pablo Saratxaga <pablo@mandrakesoft.com> 0.10.39-1mdk
- update to 0.10.39

* Thu Jul  5 2001 Guillaume Cottenceau <gc@mandrakesoft.com> 0.10.38-2mdk
- rebuild

* Tue May 29 2001 Frederic Crozat <fcrozat@mandrakesoft.com> 0.10.38-1mdk
- Release 0.10.38 (should correct po/Makefile generation problem)
- Add man pages
- No longer ship charset.alias, it was wrongly generated with previous version
(and it is not needed for system with glibc >= 2.1)

* Tue May 15 2001 Pablo Saratxaga <pablo@mandrakesoft.com> 0.10.37-3mdk
- small patch to avoid issuing warning messages fro charsets we do support

* Fri May 11 2001 Geoffrey Lee <snailtalk@mandrakesoft.com> 0.10.37-2mdk
- Fix a dangling symlink (Abel).

* Fri Apr 20 2001 Geoffrey Lee <snailtalk@mandrakesoft.com> 0.10.37-1mdk
- GNU gettext 0.10.37.
- Include the charset.alias file.

* Wed Apr 18 2001 Geoffrey Lee <snailtalk@mandrakesoft.com> 0.10.36-1mdk
- New and shiny 0.10.36.
- Patch cleanup.
- Split out the dynamic libraries.
- Remove msghack but put in ngettext.
- Don't run aclocal before ./configure.
- Use %%version in the Source tag instead of a hardcoded one.
- In the Source tag s/alpha/ftp/;

* Tue Apr 17 2001 Guillaume Cottenceau <gc@mandrakesoft.com> 0.10.35-20mdk
- move /usr/bin/gettext to /bin/gettext so that initscripts can be
  translated before /usr is ever mounted

* Tue Apr 17 2001 Jeff Garzik <jgarzik@mandrakesoft.com> 0.10.35-19mdk
- Move gettextize to devel package
- Install po/Makefile.in.in in /usr/share/gettext/po.
  gettextize was broken without this.
- Install ABOUT-NLS in /usr/share/gettext.
  gettextize was broken without this.

* Thu Mar 22 2001 Guillaume Cottenceau <gc@mandrakesoft.com> 0.10.35-18mdk
- split main package because initscripts requires gettext binary, and we
  want to have a reasonable "smallest" install
- add emacs site-start for el file
- remove elc version of the mode

* Tue Nov  7 2000 Guillaume Cottenceau <gc@mandrakesoft.com> 0.10.35-17mdk
- fix dependency on devel package
- add documentation

* Wed Aug 23 2000 Guillaume Cottenceau <gc@mandrakesoft.com> 0.10.35-16mdk
- automatically added packager tag

* Tue Aug 22 2000 Guillaume Cottenceau <gc@mandrakesoft.com> 0.10.35-15mdk
- bugfixed gettextize when headers are not there
  thanks to <rchaillat@mandrakesoft.com>

* Tue Jul 18 2000 Guillaume Cottenceau <gc@mandrakesoft.com> 0.10.35-14mdk
- macros

* Fri May  5 2000 Guillaume Cottenceau <gc@mandrakesoft.com> 0.10.35-13mdk
- quick patch to have it work!

* Sat Apr 08 2000 John Buswell <johnb@mandrakesoft.com> 0.10.35-12mdk
- added devel package

* Thu Mar 30 2000 John Buswell <johnb@mandrakesoft.com> 0.10.35-11mdk
- fixed groups
- Removed version number from spec filename
- spec-helper

* Tue Nov 02 1999 Pablo Saratxaga <pablo@mandrakesoft.com>
- rebuild for new environment

* Wed Jun 30 1999 Chmouel Boudjnah <chmouel@mandrakesoft.com>
- s/arch-RedHat/arch-Mandrake/
- msghack updates.

* Tue May 11 1999 Bernhard Rosenkraenzer <bero@mandrakesoft.com>
- Mandrake adaptions

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com> 
- auto rebuild in the new build environment (release 8)

* Mon Mar 08 1999 Cristian Gafton <gafton@redhat.com>
- added patch for misc hacks to facilitate rpm translations

* Thu Dec 03 1998 Cristian Gafton <gafton@redhat.com>
- patch to allow to build on ARM

* Wed Sep 30 1998 Jeff Johnson <jbj@redhat.com>
- add Emacs po-mode.el files.

* Sun Sep 13 1998 Cristian Gafton <gafton@redhat.com>
- include the aclocal support files

* Fri Sep  3 1998 Bill Nottingham <notting@redhat.com>
- remove devel package (functionality is in glibc)

* Tue Sep  1 1998 Jeff Johnson <jbj@redhat.com>
- update to 0.10.35.

* Mon Jun 29 1998 Jeff Johnson <jbj@redhat.com>
- add gettextize.
- create devel package for libintl.a and libgettext.h.

* Mon Apr 27 1998 Prospector System <bugs@redhat.com>
- translations modified for de, fr, tr

* Sun Nov 02 1997 Cristian Gafton <gafton@redhat.com>
- added info handling
- added misc-patch (skip emacs-lisp modofications)

* Sat Nov 01 1997 Erik Troan <ewt@redhat.com>
- removed locale.aliases as we get it from glibc now
- uses a buildroot

* Mon Jun 02 1997 Erik Troan <ewt@redhat.com>
- Built against glibc
